@@ -15,6 +15,10 @@ class GitRepo:
     def __init__(self, repo: Repository):
         self.repo = repo
 
+    @property
+    def commits_count(self) -> int:
+        return self.repo.get_commits().totalCount
+
     @property
     def language(self) -> str:
         return self.repo.language
